from PyQt5 import QtWidgets, QtCore, QtGui
import numpy as np
from astropy.wcs import WCS
import astropy.units as u
import matplotlib.pyplot as plt
from astropy.wcs.utils import pixel_to_skycoord
from matplotlib import colors
from matplotlib.cm import ScalarMappable

from .fitswidget import Ui_FitsWidget
from .norm import *


class QFitsWidget(QtWidgets.QWidget, Ui_FitsWidget):
    def __init__(self, parent=None):
        QtWidgets.QWidget.__init__(self, parent)
        self.setupUi(self)

        # mouse
        self.imageView.mouseMoved.connect(self._mouse_moved)

        # set cuts
        self.comboCuts.addItems(['100.0%', '99.9%', '99.0%', '95.0%', 'Custom'])
        self.comboCuts.setCurrentText('99.9%')
        self.comboCuts.currentTextChanged.connect(self._cuts_preset_changed)
        self.spinLoCut.valueChanged.connect(self._cuts_changed)
        self.spinHiCut.valueChanged.connect(self._cuts_changed)

        # set stretch functions
        self.comboStretch.addItems(['linear', 'log', 'sqrt', 'squared', 'asinh'])
        self.comboStretch.setCurrentText('sqrt')
        self.comboStretch.currentTextChanged.connect(self._colormap_changed)

        # set colormaps
        self.comboColormap.addItems(sorted([cm for cm in plt.colormaps() if not cm.endswith('_r')]))
        self.comboColormap.setCurrentText('gray')
        self._colormap_changed()
        self.comboColormap.currentTextChanged.connect(self._colormap_changed)
        self.checkColormapReverse.stateChanged.connect(self._colormap_changed)

        # connect trimsec
        self.checkTrimSec.stateChanged.connect(self._trimsec_changed)

        # store hdu and (scaled) data
        self.hdu = None
        self.data = None
        self.sorted_data = None
        self.scaled_data = None
        self.pixmap = None
        self.cuts = None
        self.wcs = None
        self.position_angle = None
        self.mirrored = None

    def _apply_cuts(self):
        # get cuts
        c1, c2 = self.cuts

        # scale data
        data = (self.data - c1) / (c2 - c1)

        # trim
        data[data < 0] = 0
        data[data > 1] = 1

        # back to short
        data *= 255
        self.scaled_data = np.int8(data)

        # now we need to re-create the pixmap
        self._create_qimage()

    def _create_qimage(self):
        # get shape of image
        height, width = self.scaled_data.shape[-2:]

        # format
        if len(self.scaled_data.shape) == 2:
            format = QtGui.QImage.Format_Indexed8
            bytes_per_line = width
        else:
            format = QtGui.QImage.Format_RGB888
            bytes_per_line = width * 3

        # for cubes, move axis
        data = np.moveaxis(self.scaled_data, 0, 2) if len(self.scaled_data.shape) == 3 else self.scaled_data

        # create QImage
        image = QtGui.QImage(data.tobytes(), width, height, bytes_per_line, format)

        # flip it
        flipped = image.transformed(QtGui.QTransform().scale(1, -1))

        # now we need to display it
        self.imageView.setImage(flipped, self.position_angle, self.mirrored)

    def _trimsec(self, hdu) -> np.ndarray:
        """Trim an image to TRIMSEC.

        Args:
            hdu: HDU to take data from.

        Returns:
            Numpy array with image data.
        """

        # keyword not given?
        if 'TRIMSEC' not in hdu.header:
            # return whole data
            return hdu.data

        # get value of section
        sec = hdu.header['TRIMSEC']

        # copy data
        data = hdu.data.copy()

        # split values
        s = sec[1:-1].split(',')
        x = s[0].split(':')
        y = s[1].split(':')

        # set everything else to NaN
        x0 = int(x[0]) - 1
        x1 = int(x[1])
        y0 = int(y[0]) - 1
        y1 = int(y[1])
        data[:, :x0] = 0
        data[:, x1:] = 0
        data[:y0, :] = 0
        data[y1:, :] = 0

        # return data
        return data

    def display(self, hdu):
        # check supported formats
        if len(hdu.data.shape) == 2:
            # any 2D image is supported
            pass
        elif len(hdu.data.shape) == 3:
            # we need three images of uint8 format
            if hdu.data.shape[0] != 3:
                raise ValueError('Data cubes only supported with three layers, which are interpreted as RGB.')
            if hdu.data.dtype != np.uint8:
                raise ValueError('Color images only supported in RGB24 mode.')

        # store HDU and create WCS
        self.hdu = hdu
        self.wcs = WCS(hdu.header)

        # get position angle and check whether image was mirrored
        if 'PC1_1' in self.hdu.header:
            CD11, CD12 = self.hdu.header['PC1_1'], self.hdu.header['PC1_2']
            CD21, CD22 = self.hdu.header['PC2_1'], self.hdu.header['PC2_2']
            self.position_angle = np.degrees(np.arctan2(CD12, CD11))
            self.mirrored = (CD11 * CD22 - CD12 * CD21) < 0
        else:
            self.position_angle = None
            self.mirrored = None

        # for INT8 images, we don't need cuts
        is_int8 = hdu.data.dtype == np.uint8

        # colour image?
        is_color = len(hdu.data.shape) == 3 and hdu.data.shape[0] == 3

        # enable GUI elements, only important for first image after start
        self.labelCuts.setEnabled(not is_int8)
        self.comboCuts.setEnabled(not is_int8)
        self.spinLoCut.setEnabled(not is_int8)
        self.spinHiCut.setEnabled(not is_int8)
        self.labelStretch.setEnabled(not is_int8)
        self.comboStretch.setEnabled(not is_int8)
        self.labelColormap.setEnabled(not is_color)
        self.comboColormap.setEnabled(not is_color)
        self.checkColormapReverse.setEnabled(not is_color)
        self.checkTrimSec.setEnabled(True)

        # apply trimsec
        self._trimsec_changed()

        # update info
        x, y = self.imageView.last_cursor_pos
        self._mouse_moved(x, y)

    def _trimsec_changed(self):
        # cut trimsec
        self.data = self._trimsec(self.hdu) if self.checkTrimSec.isChecked() else self.hdu.data

        # store flattened and sorted pixels
        self.sorted_data = np.sort(self.data[self.data > 0].flatten())

        # image type?
        if self.hdu.data.dtype == np.uint8:
            # image is scaled image directly
            self.scaled_data = np.copy(self.data)
            self._create_qimage()

        else:
            # apply cuts
            self._cuts_preset_changed(self.comboCuts.currentText())

    def _cuts_preset_changed(self, preset):
        if preset == 'Custom':
            # just enable text boxes
            self.spinLoCut.setEnabled(True)
            self.spinHiCut.setEnabled(True)
            return

        # get percentage
        percent = float(preset[:-1])

        # get number of pixels to discard at both ends
        n = int(len(self.sorted_data) * (1. - (percent / 100.)))

        # get min/max in cut range
        cut = self.sorted_data[n:-n] if n > 0 else self.sorted_data
        cuts = (np.min(cut), np.max(cut))

        # set them and disable text boxes
        self.spinLoCut.setValue(cuts[0])
        self.spinLoCut.setEnabled(False)
        self.spinHiCut.setValue(cuts[1])
        self.spinHiCut.setEnabled(False)

    def _cuts_changed(self):
        # get cuts
        self.cuts = (self.spinLoCut.value(), self.spinHiCut.value())

        # apply them
        self._apply_cuts()

    def _mouse_moved(self, x: float, y: float):
        # show X/Y
        self.textImageX.setText('%.3f' % x)
        self.textImageY.setText('%.3f' % (self.scaled_data.shape[-2] - y,))

        # convert to RA/Dec and show it
        try:
            coord = pixel_to_skycoord(x, y, self.wcs)
            self.textWorldRA.setText(coord.ra.to_string(u.hour, sep=':'))
            self.textWorldDec.setText(coord.dec.to_string(sep=':'))
        except ValueError:
            self.textWorldRA.clear()
            self.textWorldDec.clear()

        # get value
        try:
            iy, ix = self.hdu.data.shape[-2] - int(y), int(x)
            value = self.hdu.data[iy, ix]
        except IndexError:
            value = ''
        self.textPixelValue.setText(str(value))

        # mean/max
        try:
            # cut
            if len(self.hdu.data.shape) == 2:
                cut = self.hdu.data[iy - 10:iy + 11, ix - 10: ix + 11]
            else:
                cut = self.hdu.data[:, iy - 10:iy + 11, ix - 10: ix + 11]

            # calculate and show
            if all([s > 0 for s in cut.shape]):
                self.textAreaMean.setText('%.2f' % np.mean(cut))
                self.textAreaMax.setText('%.2f' % np.max(cut))
            else:
                self.textAreaMean.clear()
                self.textAreaMax.clear()

        except ValueError:
            # outside range
            pass

        # get zoom in and scale it to 100x100
        pix = self.imageView.cut(x, y, 10).scaled(101, 101)

        # draw central pixel
        painter = QtGui.QPainter(pix)
        painter.setPen(QtGui.QPen(QtCore.Qt.white, 1))
        painter.drawRect(48, 48, 4, 4)
        painter.setPen(QtGui.QPen(QtCore.Qt.black, 1))
        painter.drawRect(47, 47, 6, 6)
        painter.end()

        # show zoom
        self.labelZoom.setPixmap(pix)

        # get data in zoom
        x, y = int(x), int(y)


    def _colormap_changed(self):
        # get name of colormap
        name = self.comboColormap.currentText()
        if self.checkColormapReverse.isChecked():
            name += '_r'

        # get normalization
        stretch = self.comboStretch.currentText()
        if stretch == 'linear':
            norm = colors.Normalize(vmin=0, vmax=250)
        elif stretch == 'log':
            norm = colors.LogNorm(vmin=0.1, vmax=250)
        elif stretch == 'sqrt':
            norm = FuncNorm(np.sqrt, vmin=0, vmax=250)
        elif stretch == 'squared':
            norm = colors.PowerNorm(2, vmin=0, vmax=250)
        elif stretch == 'asinh':
            norm = FuncNorm(np.arcsinh, vmin=0, vmax=250)
        else:
            raise ValueError('Invalid stretch')

        # get colormap
        cm = ScalarMappable(norm=norm, cmap=plt.get_cmap(name))

        # set it
        self.imageView.setColormap(cm)

        # create colorbar image
        colorbar = QtGui.QImage(1, 256, QtGui.QImage.Format_ARGB32)
        for i in range(256):
            rgba = cm.to_rgba(i, bytes=True)
            c = QtGui.QColor(*rgba)
            colorbar.setPixelColor(0, i, c)

        # set colorbar
        self.labelColorbar.setPixmap(QtGui.QPixmap(colorbar))


__all__ = ['QFitsWidget']



from PyQt5 import QtWidgets, QtCore, QtGui
import numpy as np
from . import resources


class QImageView(QtWidgets.QWidget):
    mouseMoved = QtCore.pyqtSignal(float, float)

    def __init__(self, *args, **kwargs):
        QtWidgets.QWidget.__init__(self, *args, **kwargs)
        self._image = None
        self._scaled_pixmap = None
        self._image_rect = None
        self._colormap = None
        self._position_angle = None
        self._mirrored = None
        self._last_cursor_pos = (0, 0)

        # set mouse cursor and grab it
        self.setMouseTracking(True)
        self.setCursor(QtCore.Qt.CrossCursor)

        # grab keyboard as well
        self.setFocusPolicy(QtCore.Qt.StrongFocus)

    def setImage(self, image: QtGui.QImage, position_angle: float, mirrored: bool) -> None:
        # set the image
        self._image = image
        self._position_angle = None if position_angle is None else np.radians(position_angle)
        self._mirrored = mirrored

        # update image
        self._update_image()

    def setColormap(self, cm) -> None:
        # create colormap and set it
        self._colormap = [QtGui.qRgb(*cm.to_rgba(i, bytes=True)[:3]) for i in range(256)]

        # update image
        self._update_image()

    def _update_image(self):
        # do we have an image?
        if self._image is None:
            return

        # set colormap
        self._image.setColorTable(self._colormap)

        # scale image
        self._scale_image()

        # show it
        self.update()

    def _scale_image(self):
        # do we have an image?
        if self._image is None:
            return

        # get pixmap
        pixmap = QtGui.QPixmap(self._image)

        # resize pixmap to my own size keeping aspect ratio and mirror along X axis
        w, h = self.width(), self.height()
        self._scaled_pixmap = pixmap.scaled(w, h, QtCore.Qt.KeepAspectRatio)

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        # on resize, resize the pixmap
        self._scale_image()

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        # init painter with black background
        painter = QtGui.QPainter(self)
        painter.setBackground(QtCore.Qt.black)

        # no image?
        if self._scaled_pixmap is None:
            return

        # get x/y coordinates to draw image in centre
        w, h = self.width(), self.height()
        pw, ph = self._scaled_pixmap.width(), self._scaled_pixmap.height()
        x, y = (w - pw) / 2., (h - ph) / 2.

        # draw image
        painter.drawPixmap(x, y, self._scaled_pixmap)

        # draw coordinate system
        if self._position_angle is not None and self._mirrored is not None:
            self._draw_north_east(painter)

        # remember rect
        self._image_rect = (x, y, pw, ph)

    def _draw_north_east(self, painter):
        # define pen
        pen = QtGui.QPen()
        pen.setColor(QtCore.Qt.red)
        painter.setPen(pen)

        # font
        font = QtGui.QFont('times', 10)
        fm = QtGui.QFontMetrics(font)
        tw = fm.width('N')
        painter.setFont(font)

        # length of line and distance of text
        length = 30
        text = 40

        # draw N line
        x, y = -length * np.sin(self._position_angle), -length * np.cos(self._position_angle)
        painter.drawLine(50, 50, 50 + x, 50 + y)

        # draw N text
        x, y = -text * np.sin(self._position_angle), -text * np.cos(self._position_angle)
        painter.drawText(50 + x - tw/2, 50 + y + tw/2, 'N')

        # angle for E
        east_angle = self._position_angle - (np.pi / 2 if self._mirrored else -np.pi / 2)

        # draw E line
        x, y = -length * np.sin(east_angle), -length * np.cos(east_angle)
        painter.drawLine(50, 50, 50 + x, 50 + y)

        # draw E text
        x, y = -text * np.sin(east_angle), -text * np.cos(east_angle)
        painter.drawText(50 + x - tw/2, 50 + y + tw/2, 'E')

    def cut(self, x: float, y: float, size: int = 5):
        # extract region
        x, y = int(x), int(y)
        return QtGui.QPixmap(self._image.copy(x - size, y - size, size * 2, size * 2))

    def mouseMoveEvent(self, event: QtGui.QMouseEvent) -> None:
        if self._image_rect is None:
            return

        # calculate coordinates in image coordinates
        x = (event.x() - self._image_rect[0]) / self._image_rect[2]
        y = (event.y() - self._image_rect[1]) / self._image_rect[3]

        # trim to 0..1
        x, y = min(max(x, 0), 1),  min(max(y, 0), 1)

        # scale to full image size
        xi, yi = x * self._image.width(), y * self._image.height()

        # emit signal and accept
        self._last_cursor_pos = (xi, yi)
        self.mouseMoved.emit(xi, yi)
        event.accept()

    def keyPressEvent(self, event: QtGui.QKeyEvent) -> None:
        # get current cursor position
        cur = QtGui.QCursor()
        pos = cur.pos()

        # decice on key
        if event.key() == QtCore.Qt.Key_Left:
            cur.setPos(pos.x() - 1, pos.y())
        elif event.key() == QtCore.Qt.Key_Right:
            cur.setPos(pos.x() + 1, pos.y())
        elif event.key() == QtCore.Qt.Key_Up:
            cur.setPos(pos.x(), pos.y() - 1)
        elif event.key() == QtCore.Qt.Key_Down:
            cur.setPos(pos.x(), pos.y() + 1)

        # always let parent handle event as well
        QtWidgets.QWidget.keyPressEvent(self, event)

    @property
    def last_cursor_pos(self) -> (float, float):
        """Returns X/Y position of last cursor position."""
        return self._last_cursor_pos



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'fitswidget.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FitsWidget(object):
    def setupUi(self, FitsWidget):
        FitsWidget.setObjectName("FitsWidget")
        FitsWidget.resize(896, 553)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(FitsWidget)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupInfo = QtWidgets.QFrame(FitsWidget)
        self.groupInfo.setObjectName("groupInfo")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupInfo)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_2 = QtWidgets.QLabel(self.groupInfo)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_5.addWidget(self.label_2)
        self.textImageX = QtWidgets.QLineEdit(self.groupInfo)
        self.textImageX.setAlignment(QtCore.Qt.AlignCenter)
        self.textImageX.setReadOnly(True)
        self.textImageX.setObjectName("textImageX")
        self.horizontalLayout_5.addWidget(self.textImageX)
        self.label_3 = QtWidgets.QLabel(self.groupInfo)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_5.addWidget(self.label_3)
        self.textImageY = QtWidgets.QLineEdit(self.groupInfo)
        self.textImageY.setAlignment(QtCore.Qt.AlignCenter)
        self.textImageY.setReadOnly(True)
        self.textImageY.setObjectName("textImageY")
        self.horizontalLayout_5.addWidget(self.textImageY)
        self.label_4 = QtWidgets.QLabel(self.groupInfo)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_5.addWidget(self.label_4)
        self.textWorldRA = QtWidgets.QLineEdit(self.groupInfo)
        self.textWorldRA.setAlignment(QtCore.Qt.AlignCenter)
        self.textWorldRA.setReadOnly(True)
        self.textWorldRA.setObjectName("textWorldRA")
        self.horizontalLayout_5.addWidget(self.textWorldRA)
        self.label_5 = QtWidgets.QLabel(self.groupInfo)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_5.addWidget(self.label_5)
        self.textWorldDec = QtWidgets.QLineEdit(self.groupInfo)
        self.textWorldDec.setAlignment(QtCore.Qt.AlignCenter)
        self.textWorldDec.setReadOnly(True)
        self.textWorldDec.setObjectName("textWorldDec")
        self.horizontalLayout_5.addWidget(self.textWorldDec)
        self.verticalLayout.addWidget(self.groupInfo)
        self.frame_2 = QtWidgets.QFrame(FitsWidget)
        self.frame_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.frame_2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_7 = QtWidgets.QLabel(self.frame_2)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout.addWidget(self.label_7)
        self.textPixelValue = QtWidgets.QLineEdit(self.frame_2)
        self.textPixelValue.setAlignment(QtCore.Qt.AlignCenter)
        self.textPixelValue.setReadOnly(True)
        self.textPixelValue.setObjectName("textPixelValue")
        self.horizontalLayout.addWidget(self.textPixelValue)
        self.label_11 = QtWidgets.QLabel(self.frame_2)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout.addWidget(self.label_11)
        self.textAreaMean = QtWidgets.QLineEdit(self.frame_2)
        self.textAreaMean.setAlignment(QtCore.Qt.AlignCenter)
        self.textAreaMean.setReadOnly(True)
        self.textAreaMean.setObjectName("textAreaMean")
        self.horizontalLayout.addWidget(self.textAreaMean)
        self.label_12 = QtWidgets.QLabel(self.frame_2)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout.addWidget(self.label_12)
        self.textAreaMax = QtWidgets.QLineEdit(self.frame_2)
        self.textAreaMax.setAlignment(QtCore.Qt.AlignCenter)
        self.textAreaMax.setReadOnly(True)
        self.textAreaMax.setObjectName("textAreaMax")
        self.horizontalLayout.addWidget(self.textAreaMax)
        self.verticalLayout.addWidget(self.frame_2)
        self.horizontalLayout_4.addLayout(self.verticalLayout)
        self.labelZoom = QtWidgets.QLabel(FitsWidget)
        self.labelZoom.setMinimumSize(QtCore.QSize(101, 101))
        self.labelZoom.setMaximumSize(QtCore.QSize(101, 101))
        self.labelZoom.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.labelZoom.setFrameShadow(QtWidgets.QFrame.Raised)
        self.labelZoom.setText("")
        self.labelZoom.setScaledContents(True)
        self.labelZoom.setObjectName("labelZoom")
        self.horizontalLayout_4.addWidget(self.labelZoom)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.imageView = QImageView(FitsWidget)
        self.imageView.setObjectName("imageView")
        self.horizontalLayout_2.addWidget(self.imageView)
        self.labelColorbar = QtWidgets.QLabel(FitsWidget)
        self.labelColorbar.setMinimumSize(QtCore.QSize(30, 0))
        self.labelColorbar.setMaximumSize(QtCore.QSize(30, 16777215))
        self.labelColorbar.setText("")
        self.labelColorbar.setScaledContents(True)
        self.labelColorbar.setObjectName("labelColorbar")
        self.horizontalLayout_2.addWidget(self.labelColorbar)
        self.horizontalLayout_2.setStretch(0, 1)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.frame = QtWidgets.QFrame(FitsWidget)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.labelCuts = QtWidgets.QLabel(self.frame)
        self.labelCuts.setEnabled(False)
        self.labelCuts.setObjectName("labelCuts")
        self.horizontalLayout_3.addWidget(self.labelCuts)
        self.comboCuts = QtWidgets.QComboBox(self.frame)
        self.comboCuts.setEnabled(False)
        self.comboCuts.setObjectName("comboCuts")
        self.horizontalLayout_3.addWidget(self.comboCuts)
        self.spinLoCut = QtWidgets.QDoubleSpinBox(self.frame)
        self.spinLoCut.setEnabled(False)
        self.spinLoCut.setMinimum(-999999999.0)
        self.spinLoCut.setMaximum(999999999.0)
        self.spinLoCut.setObjectName("spinLoCut")
        self.horizontalLayout_3.addWidget(self.spinLoCut)
        self.spinHiCut = QtWidgets.QDoubleSpinBox(self.frame)
        self.spinHiCut.setEnabled(False)
        self.spinHiCut.setMinimum(-999999999.0)
        self.spinHiCut.setMaximum(999999999.0)
        self.spinHiCut.setObjectName("spinHiCut")
        self.horizontalLayout_3.addWidget(self.spinHiCut)
        spacerItem = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.labelStretch = QtWidgets.QLabel(self.frame)
        self.labelStretch.setEnabled(False)
        self.labelStretch.setObjectName("labelStretch")
        self.horizontalLayout_3.addWidget(self.labelStretch)
        self.comboStretch = QtWidgets.QComboBox(self.frame)
        self.comboStretch.setEnabled(False)
        self.comboStretch.setObjectName("comboStretch")
        self.horizontalLayout_3.addWidget(self.comboStretch)
        spacerItem1 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.labelColormap = QtWidgets.QLabel(self.frame)
        self.labelColormap.setEnabled(False)
        self.labelColormap.setObjectName("labelColormap")
        self.horizontalLayout_3.addWidget(self.labelColormap)
        self.comboColormap = QtWidgets.QComboBox(self.frame)
        self.comboColormap.setEnabled(False)
        self.comboColormap.setObjectName("comboColormap")
        self.horizontalLayout_3.addWidget(self.comboColormap)
        self.checkColormapReverse = QtWidgets.QCheckBox(self.frame)
        self.checkColormapReverse.setEnabled(False)
        self.checkColormapReverse.setObjectName("checkColormapReverse")
        self.horizontalLayout_3.addWidget(self.checkColormapReverse)
        spacerItem2 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.checkTrimSec = QtWidgets.QCheckBox(self.frame)
        self.checkTrimSec.setEnabled(False)
        self.checkTrimSec.setChecked(True)
        self.checkTrimSec.setObjectName("checkTrimSec")
        self.horizontalLayout_3.addWidget(self.checkTrimSec)
        self.verticalLayout_2.addWidget(self.frame)
        self.verticalLayout_2.setStretch(1, 1)

        self.retranslateUi(FitsWidget)
        QtCore.QMetaObject.connectSlotsByName(FitsWidget)

    def retranslateUi(self, FitsWidget):
        _translate = QtCore.QCoreApplication.translate
        FitsWidget.setWindowTitle(_translate("FitsWidget", "Form"))
        self.label_2.setText(_translate("FitsWidget", "X:"))
        self.label_3.setText(_translate("FitsWidget", "Y:"))
        self.label_4.setText(_translate("FitsWidget", "RA:"))
        self.label_5.setText(_translate("FitsWidget", "Dec:"))
        self.label_7.setText(_translate("FitsWidget", "Value:"))
        self.label_11.setText(_translate("FitsWidget", "Mean:"))
        self.label_12.setText(_translate("FitsWidget", "Max:"))
        self.labelCuts.setText(_translate("FitsWidget", "Cuts:"))
        self.labelStretch.setText(_translate("FitsWidget", "Stretch:"))
        self.labelColormap.setText(_translate("FitsWidget", "Colormap:"))
        self.checkColormapReverse.setText(_translate("FitsWidget", "reversed"))
        self.checkTrimSec.setText(_translate("FitsWidget", "trimsec"))
from .qimageview import QImageView



#!/usr/bin/env python3
from setuptools import setup

setup(
    name='qfitswidget',
    version='0.7.1',
    description='PyQt widget for displaying FITS files',
    author='Tim-Oliver Husser',
    author_email='thusser@uni-goettingen.de',
    packages=['qfitswidget'],
    install_requires=[
        'matplotlib',
        'PyQt5',
        'numpy',
        'astropy'
    ]
)
